#!/bin/bash
if [ -r ../syn/syn_cfg.txt ]; then
    SYN_CFG=`cat ../syn/syn_cfg.txt`
else
    SYN_CFG="CPU_12_4"
fi

CORE_DIR=../../cores
if [ "$SYN_CFG" == "CPU_14_7" ]; then
    CPU_DIR=../cpu_14_7/implementation
else
    CPU_DIR=../cpu/implementation
fi
SRC_DIR=../src
XST_DIR=../xst
XST_OC_DIR=../xst_open_camera
args=("$@")
if [ $# -eq 1 ]; then
   echo "*****************************************"
   echo "ngdbuild"
   echo "Number of arguments passed: $#"
   PRO="${args[0]}"
   echo "starting ngdbuild for project $PRO"
   echo "see logfile $PRO.ngdbuild_log"
   echo "*****************************************"
else
   echo "*****************************************"
   echo Number of arguments passed: $#
   echo
   echo "usage: ./ngdbuild.sh <project>"
   echo "*****************************************"
   exit 1
fi
if [ -d ngd ]; then
rm -rf ngd
fi
mkdir ngd
cd ngd
NGDBUILD="ngdbuild -intstyle xflow -dd _ngo -sd $CORE_DIR -sd $CPU_DIR -sd $XST_OC_DIR -nt timestamp -uc $SRC_DIR/$PRO.ucf -bm $SRC_DIR/edkBmmFile.bmm $XST_DIR/$PRO.ngc $PRO.ngd"

if [ -d $CORE_DIR ]; then
   echo "Found core directory: $CORE_DIR"
   else
   echo "No core directory $CORE_DIR"
   exit 1
fi
if [ -d $SRC_DIR ]; then
   echo "Found src directory: $SRC_DIR"
   else
   echo "No src directory $SRC_DIR"
   exit 1
fi
   if [ -r $SRC_DIR/$PRO.ucf ]; then
   echo "Found ucf file $SRC_DIR/$PRO.ucf"
   else
   echo "No ucf file Table $SRC_DIR/$PRO.ucf"
   exit 1
fi
if [ -r $SRC_DIR/edkBmmFile.bmm ]; then
   echo "Found bmm file $SRC_DIR/edkBmmFile.bmm"
   else
   echo "No bmm file Table $SRC_DIR/edkBmmFile.bmm"
   exit 1
fi
if [ -r $XST_DIR/$PRO.ngc ]; then
   echo "Found ngc file $XST_DIR/$PRO.ngc"
   else
   echo "No ngc file Table $XST_DIR/$PRO.ngc"
   exit 1
fi

XIL_PAR_DESIGN_CHECK_VERBOSE=1
date > $PRO.ngdbuild_log
echo $NGDBUILD
$NGDBUILD | tee -a $PRO.ngdbuild_log
if [ ${PIPESTATUS[0]} != 0 ]; then
   exit 1
fi
date >> $PRO.ngdbuild_log
cd ..
exit;
