#!/bin/bash
CUR_DIR=$PWD
SRC_DIR=src
SRC_OC_DIR=src_open_camera
PAR_DIR=par
TIM_DIR=tim
BIT_DIR=bit
MAP_DIR=map
NGD_DIR=ngd
XST_DIR=xst
XST_OC_DIR=xst_open_camera
SYN_DIR=../syn
BIN_DIR=fw/bin

XST_SCR=$CUR_DIR/$SYN_DIR/xst.sh
MAP_SCR=$CUR_DIR/$SYN_DIR/map.sh
PAR_SCR=$CUR_DIR/$SYN_DIR/par.sh
NGD_SCR=$CUR_DIR/$SYN_DIR/ngdbuild.sh
BIT_SCR=$CUR_DIR/$SYN_DIR/bit.sh
TRC_SCR=$CUR_DIR/$SYN_DIR/trce.sh

function header {
      echo "***********************************************************"
      echo "synthesis for project $PRO in ${PWD##*/}"
}
function usage {
      header
      echo "run in gige-___ or gvrd-___ project directory!"
      echo "***********************************************************"
      echo "run actual project with default t-paramter 1:"
      echo "./syn.sh"
      echo "***********************************************************"
      echo "run actual project with new t-paramter:"
      echo "./syn.sh <1-100>"
      echo "***********************************************************"
      echo "clean subdirs"
      echo "./syn.sh C0 == rem all subdirs"
      echo "./syn.sh C1 == keep xst"
      echo "./syn.sh C2 == keep xst+ngd"
      echo "./syn.sh C3 == rem tim-par-bit"
      echo "./syn.sh C4 == rem bit"
      echo "***********************************************************"
      echo "synthesis only: syn.sh XST_ONLY"
      echo "***********************************************************"
}
function scr_run {
    "$@"
    status=$?
    if [ $status -ne 0 ]; then
        echo "error in $@"
       # usage
        exit 1;
    fi
    return $status
}
PROJ=$(pwd | gawk -F / '{split($NF,b,"-"); print b[1]}')
if [ $PROJ == "gige" ]; then
   PRO=gige_top
else if [ $PROJ == "gvrd" ]; then
      PRO=gvrd
     else
     echo "unknow project type"
      usage
     exit 1;
     fi
fi
args=("$@")
if [ $# -eq 0 ]; then
T_PARA=1
else
   if [ $# -eq 1 ]; then
      T_PARA="${args[0]}"
     if [[ $T_PARA == -h || $T_PARA == help || $T_PARA -gt 100 ]]; then
        usage
        exit;
     fi
   else
     usage
     exit 1;
   fi
fi

if [[ $T_PARA == C0 ]]; then

   if [ -r $SRC_OC_DIR ]; then
     rm -rf $XST_OC_DIR
     echo  "rm -rf $XST_OC_DIR"
   fi
   
   # do not remove xst dir when not a project file exists (required for delivery)
   if [ -r $SRC_DIR/$PRO.prj ]; then
     rm -rf $XST_DIR
     echo  "rm -rf $XST_DIR"
   fi
   
fi
if [[ $T_PARA == C0 || $T_PARA == C1 ]]; then
   rm -rf $NGD_DIR
   echo  "rm -rf $NGD_DIR"
fi
if [[ $T_PARA == C0 || $T_PARA == C1 || $T_PARA == C2 ]]; then
   rm -rf $MAP_DIR
   echo  "rm -rf $MAP_DIR"
fi
if [[ $T_PARA == C0 || $T_PARA == C1 || $T_PARA == C2 || $T_PARA == C3 ]]; then
   rm -rf $PAR_DIR
   rm -rf $TIM_DIR
   echo  "rm -rf $TIM_DIR $PAR_DIR"
fi
if [[ $T_PARA == C0 || $T_PARA == C1 || $T_PARA == C2 || $T_PARA == C3 || $T_PARA == C4 ]]; then
   rm -rf $BIT_DIR
   echo  "rm -rf $BIT_DIR"
   exit;
fi
   
   if [ -r $SRC_OC_DIR ]; then
     if [ -r $XST_OC_DIR ]; then
       echo "Found $XST_OC_DIR"
     else
       scr_run $XST_SCR CustomModule $SRC_OC_DIR $XST_OC_DIR xst_run_open_camera.txt
     fi
   fi
   
   
   if [ -r $XST_DIR ]; then
     echo "Found $XST_DIR"
   else
     scr_run $XST_SCR $PRO $SRC_DIR $XST_DIR xst_run.txt
   fi
   
   if [[ T_PARA == XST_ONLY ]]; then
     exit 0
   fi
   
   if [ -r $NGD_DIR ]; then
      echo "Found $NGD_DIR"
   else
     scr_run $NGD_SCR $PRO
   fi

   if [ -r $MAP_DIR ]; then
     echo "Found $MAP_DIR"
   else
     scr_run $MAP_SCR $PRO $T_PARA
   fi

   if [ -r $PAR_DIR ]; then
     echo "Found $PAR_DIR"
   else
     scr_run $PAR_SCR $PRO
   fi

   if [ -r $TIM_DIR ]; then
     echo "Found $TIM_DIR"
   else
     scr_run $TRC_SCR $PRO
   fi
   
   if [ -r $BIT_DIR ]; then
     echo "Found $BIT_DIR"
   else
     scr_run $BIT_SCR $PRO
   fi
   
   
   if [ -r $BIN_DIR ]; then
     echo "Found $BIN_DIR"
     TEMP=$(date +%d%h%H%M)
     BACKUP=$BIN_DIR$TEMP
     cp -rp $BIN_DIR $BACKUP
   fi
   
   if [ -r fw/Makefile ]; then
   
     make -C fw clean
     make -C fw syn
     make -C fw
     echo "***********************************************************"
     echo "***********************************************************"
     echo "synthesis for project $PRO in ${PWD##*/} finished"
     echo "bitstream and fw generation in ${PWD##*/}/$BIN_DIR"
     echo "saved previous bitstream directory to $BACKUP"
     echo "***********************************************************"
     echo "***********************************************************"
     exit;

   fi
