-------------------------------------------------------------------------------
-- Project    : GigEpro
-- Title      : Package for Custom Module Wrapper
-------------------------------------------------------------------------------
-- Copyright (c) 2013 NET New Electronic Technology GmbH
-------------------------------------------------------------------------------
-- Revisions  : Date        Version  Author   Description
--              2013-05-20  1.0      Manfred  Created
--              2015-04-16  2.0      a.kramer Changed for GigEpro
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

package WrapperPkg is

    ----------------------------------------------------------------------------
    -- ImageBus Definitions - DO NOT MODIFY
    ----------------------------------------------------------------------------
    constant cIMG_STAT_WIDTH  : integer   := 3;     -- ImageBus Status Bus Width  
    constant cIMG_DATA_WIDTH  : integer   := 36;    -- ImageBus Data Bus Width  
   
    constant cIMG_STAT_NONE   : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "000";   -- No status
    constant cIMG_STAT_SOF    : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "001";   -- Start Of Frame
    constant cIMG_STAT_SOSF   : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "010";   -- Start Of Single-Line Frame (Linescan)
    constant cIMG_STAT_SOL    : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "100";   -- Start Of Line
    constant cIMG_STAT_SOLL   : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "101";   -- Start Of Last Line
    constant cIMG_STAT_EOL    : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "110";   -- End Of Line
    constant cIMG_STAT_ERR    : std_logic_vector(cIMG_STAT_WIDTH-1 downto 0) := "111";   -- Data Error

    ----------------------------------------------------------------------------
    -- SystemBus Definitions - DO NOT MODIFY
    ----------------------------------------------------------------------------
    constant cLVSB_DESIGN_ID  : integer   := 47;        -- LVSB Module Design ID - DO NOT MODIFY
    constant cSYS_ADDR_WIDTH  : integer   := 17;        -- Width of SystemBus Address Bus
    constant cSYS_DATA_WIDTH  : integer   := 32;        -- Width of SystemBus Data Bus

end WrapperPkg;
