#!/bin/bash
BL_DIR=../../fw/lib
BIN_DIR=../fw/bin
PAR_DIR=../par
SRC_DIR=../src
SCR_DIR=../../syn
BL_FILE=$BL_DIR/bootloader_NET_64M_4Gb.elf
BD_FILE=$SRC_DIR/edkBmmFile_bd.bmm


args=("$@")
usage ()
{
   echo "*****************************************"
   echo Number of arguments passed: $#
   echo
   echo "usage: ./bit.sh <project>"
   echo "*****************************************"
   exit 1;
}
if [ $# -eq 1 ]; then
   echo "*****************************************"
   echo "bit"
   echo "Number of arguments passed: $#"
   PRO="${args[0]}"
   echo "starting bitgen for project $PRO"
   echo "see logfile $PRO.bit_log"
   echo "*****************************************"
else
   usage
fi

if [ -d bit ]; then
   rm -rf bit
   fi
   mkdir bit
   cd bit
   if [ -r $PAR_DIR/$PRO.ncd ]; then
     echo "Found ncd file $PAR_DIR/$PRO.ncd"
   else
     echo "No ncd file $PRO.ncd"
     exit 1;
   fi
   if [ -r $SCR_DIR/bit.ut ]; then
     echo "Found ut file $SCR_DIR/bit.ut "
   else
     echo "No ut file $SCR_DIR/bit.ut "
     exit 1;
   fi
   if [ -r $BL_FILE ]; then
      echo "Found bootloader file $BL_FILE"
      else
      echo "No bootloader $BL_FILE"
      usage
   fi
   date > $PRO.bit_log
  
   RUN_BITGEN="-intstyle xflow -f $SCR_DIR/bit.ut -bd $BL_FILE $PAR_DIR/$PRO.ncd bitstream.bit"  
   echo "running bitgen $RUN_BITGEN| tee -a $PRO.bit_log "

   bitgen $RUN_BITGEN| tee -a $PRO.bit_log
# bitgen [-d] [-j] [-b] [-w] [-l] [-m] [-t] [-n] [-u] [-a] [-r <bitFile>]
# [-intstyle ise|xflow|silent|pa] [-ise <projectrepositoryfile>] {-bd
# <BRAM_data_file> [tag <tagname>]} {-g <setting_value>} [-filter
# <filter_file[.filter]>] <infile[.ncd]> [<outfile>] [<pcffile[.pcf]>]
# Where:
  # -d            = Don't Run DRC (Design Rules Checker)
  # -j            = Don't create bit file
  # -b            = Create rawbits file
  # -w            = Overwrite existing output file
  # -l            = Create logic allocation file
  # -m            = Create mask file
  # -f <cmdfile>  = Read command line arguments from file <cmdfile>
  # -r <bitfile>  = Create a partial bit file using <bitfile> as reference
  # -bd <memfile> = Update BlockRAM contents with data from file <memfile>
  # -g <opt:val>  = Set option to value, options are (1st is default):
  # options for bit.ut file:
  # Compress
  # Readback
  # CRC                Enable, Disable
  # DebugBitstream     No, Yes
  # ConfigRate         2, 1, 4, 6, 10, 12, 16, 22, 26
  # StartupClk         Cclk, UserClk, JtagClk
  # DonePin            Pullup, Pullnone
  # ProgPin            Pullup, Pullnone
  # TckPin             Pullup, Pulldown, Pullnone
  # TdiPin             Pullup, Pulldown, Pullnone
  # TdoPin             Pullup, Pulldown, Pullnone
  # TmsPin             Pullup, Pulldown, Pullnone
  # UnusedPin          Pulldown, Pullup, Pullnone
  # GWE_cycle          6, 1, 2, 3, 4, 5, Done, Keep
  # GTS_cycle          5, 1, 2, 3, 4, 6, Done, Keep
  # LCK_cycle          NoWait, 1, 2, 3, 4, 5, 6
  # DONE_cycle         4, 1, 2, 3, 5, 6
  # Persist            No, Yes
  # DriveDone          No, Yes
  # DonePipe           No, Yes
  # Security           None, Level1, Level2, Level3
  # UserID             0xFFFFFFFF, <hex string>
  # ActiveReconfig     No, Yes
  # Encrypt            No, Yes
  # Key0               pick, <string>
  # StartCBC           pick, <string>
  # KeyFile            <string>
  # drive_awake        No, Yes
  # Reset_on_err       No, Yes
  # en_sw_gsr          No, Yes
  # sw_clk             Startupclk, Internalclk
  # sw_gwe_cycle       5, <string>
  # sw_gts_cycle       4, <string>
  # multipin_wakeup    No, Yes
  # wakeup_mask        0x00, <hex string>
  # ExtMasterCclk_en   No, Yes
  # ExtMasterCclk_divide 1, <string>
  # glutmask           Yes, No
  # next_config_addr   0x00000000, <hex string>
  # next_config_new_mode No, Yes
  # next_config_boot_mode 001, <binary string>
  # next_config_register_write Enable, Disable
  # golden_config_addr 0x00000000, <hex string>
  # failsafe_user      0x0000, <hex string>
  # TIMER_CFG          None, <string>
  # spi_buswidth       1, 2, 4
  # IEEE1532           No, Yes
  # Binary             No, Yes

   #if [ -r $BD_FILE ]; then
   #   echo "Found edkBmmFile_bd.bmm file $BD_FILE"
   #   else
   #   echo "No edkBmmFile_bd.bmm $BD_FILE"
   #   exit 1;
   #fi
   #echo "data2mem -bm $BD_FILE -bt bitstream.bit -bd $BL_FILE tag microblaze_0 -o b $PRO.bit"
   #data2mem -bm $BD_FILE -bt bitstream.bit -bd $BL_FILE tag microblaze_0 -o b $PRO.bit | tee -a $PRO.bit_log
   promgen -spi -p mcs -w -c FF -s 8192 -o bitstream.mcs -u 0 bitstream.bit
   promgen -spi -p bin -w -c FF -s 8192 -o bitstream.bin -u 0 bitstream.bit | tee -a $PRO.bit_log
   date >> $PRO.bit_log
   cd ..
exit;

# Data2MEM  <-bm FILENAME [.bmm]> |
          # <<[-bm FILENAME [.bmm]]>
           # <-bd FILENAME [<.elf>|<.mem>] [<[<boot [ADDRESS]>] tag TagName <TagName>...>]>...
           # <-o <u|v|h|m|b|p> FILENAME [.ucf|.v|.vhd|.mem|.bit|.bmm]>
           # <-p PARTNAME>
           # -i>> |
          # <<-bd FILENAME [.elf]> -d [e|r]> [<-o m FILENAME [.mem]>]>> |
          # <<-bm FILENAME [.bmm]>
           # <-bd FILENAME [<.elf>|<.mem>] [<[<boot [ADDRESS]>] tag TagName <TagName>...>]>...
           # <-bt FILENAME [.bit]> <-o b FILENAME [.bit]>> |
          # <<-bm FILENAME [.bmm]> <-bt FILENAME [.bit]> -d>> |
          # <-bx [FILEPATH]> |
          # <-mf <p PNAME PTYPE PID <a SNAME MTYPE ASTART BWIDTH <s BSIZE DWIDTH IBASE>...>...>...>> |
          # <<-pp FILENAME [.bmm]> <-o p FILENAME [.bmm]>> |
          # <-f FILENAME [.opt]> |
          # <-w [on|off] > |
          # <-q [s|e|w|i]> |
          # <-intstyle silent|ise|xflow> |
          # <-log [FILENAME [.dmr]]> |
          # <-u> |
          # <-h [ <option [< option>...]> | support ]>
# -h option_list | all | sup[port]
     # Print help text for command line options.  If only a '-h' is given, then
     # only the option summary is output. If the '-h' is followed by a space
     # separated list of option names (without the dash), help is output for
     # the listed options.  For example, '-h bm bd i' gives help on the 'bm',
     # 'bd', and 'i' options.  Use '-h all' for help on all options.  Lastly,
     # use '-h support' to list the devices Data2MEM supports.  The
     # keyword 'support' can be abbreviated up to 'sup'.

