#!/bin/bash
NGD_DIR=../ngd
args=("$@")
# MAP:  Maps the logic gates of the user's design (previously written to an NGD
# file by NGDBUILD) into the Slices and IOBs of the physical device, and writes
# out this physical design to an NCD file.
MAP_OPTIONS="-detail -w -logic_opt on -ol high -xt 0 -r 4 -global_opt off -ir off -pr b -lc auto -power off "

if [ $# -eq 2 ]; then
   echo "*****************************************"
   echo "map"
   echo "Number of arguments passed: $#"
   PRO="${args[0]}"
   T_PARA="${args[1]}"
   echo "starting map for project $PRO"
   echo "t parameter for map: $T_PARA"
   echo "see logfile $PRO.map_log"
   echo "*****************************************"
else
   echo "*****************************************"
   echo Number of arguments passed: $#
   echo
   echo "usage: ./map.sh <project> <t-param[1-100]>"
   echo "*****************************************"
   exit 1
fi
XIL_PAR_DESIGN_CHECK_VERBOSE=1
if [ -d map ]; then
rm -rf map
fi
mkdir map
cd map
if [ -r $NGD_DIR/$PRO.ngd ]; then
   echo "Found ngd file $NGD_DIR/$PRO.ngd"
   else
   echo "No ngd file $NGD_DIR/$PRO.ngd"
   exit 1
fi
date > $PRO.map_log
case "$NUMBER_OF_PROCESSORS" in
  1)
    MT=1;
     ;;
  2)
    MT=1;
     ;;
  4)
    MT=2
     ;;
  *)
      NUMBER_OF_PROCESSORS=`cat /proc/cpuinfo | grep processor | wc -l`
      if [ $NUMBER_OF_PROCESSORS -gt 2 ]; then
        MT=2
      else
        MT=1
      fi
     ;;
esac
#MT=1
MAP="map $MAP_OPTIONS -t $T_PARA -mt $MT -o $PRO.ncd $NGD_DIR/$PRO.ngd $NGD_DIR/$PRO.pcf"
echo "use $MT for map"
echo $MAP
$MAP | tee -a $PRO.map_log
if [ ${PIPESTATUS[0]} != 0 ]; then
   exit 1
fi
date >> $PRO.map_log
cd ..
exit;
# Release 12.4 - Map M.81d (nt)
# Usage: map [-p <part>] [options] [-o <outfile[.ncd]>] <infile[.ngd]>
           # [<pcffile[.pcf]>]
   # where:
   # -activityfile <activityfile.vcd|.saif> 
           # Switching activity data file to guide power optimizations.
           # Requires -power on and/or -global_opt power.
   # -bp     Map slice logic into unused block RAMs.
   # -c 1|100
           # Pack unrelated logic into clbs.  <packfactor> indicates what % of 
           # Slice resources to target.  "1" indicates maximum compression.
   # -detail           
           # Print a more verbose map report. 
   # -equivalent_register_removal on|off
           # Remove redundant registers during global optimization (default is 
           # on).
   # -f <cmdfile>
           # Read command line arguments from file <cmdfile>.
   # -filter  
           # Message Filter file name (for example "filter.filter"). If specified,
           # the contents of this file will be used to filter messages from this 
           # application. The filter file can be created using Xreport.
   # -global_opt off|area|power|speed
           # Perform global optimization before mapping (default is off).
   # -ignore_keep_hierarchy
           # Ignore any KEEP_HIERARCHY properties attached to blocks
   # -intstyle ise|xflow|silent
           # Reduce the screen output.
   # -ir [off|place|all]
           # Do not use RLOC constraints to generate RPMs. Default is "off".
           # Use RLOCs to group logic together within a Slice, but not to
           # control the relative placement of Slices with respect to each other.
   # -ise <iseProjectFile>
           # Use supplied ISE project file.
   # -lc off|area|auto
           # LUT Combining.  Merges pairs of Look Up Tables (LUTs) with common 
           # inputs into single dual output LUT6s in order to improve area. 
           # Default: off
   # -logic_opt off|on 
           # Perform post-placement physical synthesis combinatorial logic
           # optimizations during timing driven packing (default is off). 
   # -mt off|2|3|4
           # Multi-threading. Default is "off". Currently number of cores are 
           # limited to 2.
   # -ntd    Perform non-timing driven placement.
   # -o <outputfile>
           # Specify the output file name.
   # -ol std|high 
           # Effort level.
   # -p <partname> 
           # Map to part <partname>.
   # -power off|on|high|xe     
           # Power optimizations.
           # "off" is default and turns off optimizations
           # "on" Uses placement optimizations
           # "high" Applies fine grain slice clock gating optimizations 
           # "xe" Combines both placement and slice clock gating optimizations
   # -pr i|o|b
           # Pack internal flops/latches into input (i), output (o), or
           # both (b) types of IOBs.
   # -r 4|8|off
           # Control register ordering to group registers forming a bus into 
           # ordered sequences packed in a slice.
           # "4" 4 registers per slice unless sourced by a LUT (default).
           # "8" 8 registers per slice.
           # "off" no register ordering.
   # -register_duplication [off|on]
           # Duplicate registers/luts during timing-driven packing 
           # in order to improve timing.
   # -retiming off|on
           # Run register retiming during global optimization (default is off).
   # -smartguide <guidefile>
           # Enables SmartGuide using guidefile.ncd as the guide file.  
           # guidefile.ncd must be a placed and routed ncd.
   # -t <costtable>    
           # Timing-driven cost table entry.  Range:  1 <= <costtable> <= 100 
           # (default is 1).
   # -u      Do not remove unnecessary/disabled logic.
   # -w      Always overwrite any existing output files.
   # -x      Enable Performance Evaluation Mode. In this mode, the tools will
           # ignore any timing constraints specified in a constraints file and 
           # auto-generate timing constraints to drive tool performance.
   # -xe c|n Extra effort level for timing-driven packing.  'c' means continue
           # to improve timing even if timing constraints cannot be met.
           # 'n' means try additional algorithms to meet timing.
   # -xt <costtable>
           # Extra Cost Table entry, would equate to a set of env vars for
           # routability. Range:   0 <= <costtable> <= 5 (default is 0).


