#!/bin/bash
MAP_DIR=../map
NGD_DIR=../ngd
args=("$@")
# PAR: Places and Routes a design's logic components (mapped physical logic
# cells) contained within a NCD file based on the layout and timing
# requirements specified within the Physical Constraints File (PCF).
if [ $# -eq 1 ]; then
   echo "*****************************************"
   echo "par"
   echo "Number of arguments passed: $#"
   PRO="${args[0]}"
   echo "starting par for project $PRO"
   echo "see logfile $PRO.par_log"
   echo "*****************************************"
else
   echo "*****************************************"
   echo Number of arguments passed: $#
   echo
   echo "usage: ./par.sh <project>"
   echo "*****************************************"
   exit 1
fi
if [ -d par ]; then
rm -rf par
fi
mkdir par
cd par
if [ -r $MAP_DIR/$PRO.ncd ]; then
   echo "Found ncd file $PRO.ncd"
   else
   echo "No ncd file $PRO.ncd"
   exit 1
fi
if [ -r $NGD_DIR/$PRO.pcf ]; then
   echo "Found pcf file $PRO.pcf"
   else
   echo "No pcf file $PRO.pcf"
   exit 1
fi
date > $PRO.par_log
case "$NUMBER_OF_PROCESSORS" in
  1)
    MT=1;
     ;;
  2)
    MT=1;
     ;;
  4)
    MT=3
     ;;
  *)
      NUMBER_OF_PROCESSORS=`cat /proc/cpuinfo | grep processor | wc -l`
      if [ $NUMBER_OF_PROCESSORS -gt 2 ]; then
        MT=3
      else
        MT=1
      fi
     ;;
esac
#PAR="par -w -intstyle xflow -mt $MT $MAP_DIR/$PRO.ncd $PRO.ncd $NGD_DIR/$PRO.pcf"
PAR="par -w -intstyle xflow -mt 4 $MAP_DIR/$PRO.ncd $PRO.ncd $NGD_DIR/$PRO.pcf"

echo "use $MT for par"
date > $PRO.par_log
echo $PAR
$PAR | tee -a $PRO.par_log
if [ ${PIPESTATUS[0]} != 0 ]; then
   exit 1
fi
date >> $PRO.par_log
cd ..
exit;
# Usage: par [-ol std|high] [-xe n|c] [-mt on|off|1|2|3|4] [-t <costtable:1,100>] [-p] [-k]
# [-r] [-w] [-smartguide <guidefile[.ncd]>] [-x] [-nopad] [-power on|off|xe] [-activityfile <activityfile[.vcd|.saif]>]
# [-ntd] [-intstyle ise|xflow|silent] [-ise <projectrepositoryfile>] [-filter <filter_file[.filter]>] <infile[.ncd]>
# <outfile> [<constraintsfile[.pcf]>]
# Where:
   # -ol = Overall effort level. high is maximum effort.
         # Default: std (standard) for older architectures
                  # high for Virtex5, Virtex6 and Spartan6
   # -xe = Extra effort level. c (Continue on Impossible) is maximum effort.
         # Default: none
   # -mt = Multi-threading enabled. 4 is the maximum number of threads.
         # Default: off
         # Supported only for virtex5, virtex6, spartan6 and higher architectures.
   # -p =  Don't run the placer. (Keep current placement)
   # -k =  Re-entrant route. Keep the current placement. Continue the routing
         # using the existing routing as a starting point.
   # -r =  Don't run the router.
   # -w =  Overwrite. Allows overwrite of an existing file (including input
         # file). If specified output is a directory, allows files in
         # directory to be overwritten.
   # -f =  Read par command line arguments and switches from file.
   # -filter = Message Filter file name (for example "filter.filter"). If
         # specified, the contents of this file will be used to filter messages
         # from this application. The filter file can be created using Xreport.
   # -smartguide = Enables SmartGuide using guidefile.ncd as the guide file.
   # -x =  Ignore user timing constraints in physical constraints file and
         # generate timing constraints automatically for all internal clocks to
         # increase performance. Note: the level of performance achieved will
         # be dictated by the effort level (-ol std|high) chosen.
   # -nopad = Turns off generation of the pad report.
         # Default: Pad Report Generated
   # -power = Power Aware Par.  Optimizes the capacitance of non-timing-driven
            # design signals.
         # Default: off
   # -activityfile <activityfile.vcd|saif> = Switching activity data file to
            # guide power optimization.  This option is only valid if the
            # "-power on" option has been used.
   # -intstyle = Indicate contextual information when invoking Xilinx applications
         # within a flow or project environment.
         # The mode "xflow" indicates that the program is being run as part of a
         # batch flow. The mode "silent" indicates that no output will be
         # displayed to the screen. The mode "ise" indicates that the program is being
         # run as part of an integrated design environment.
         # Default: Program is run as a standalone application.
   # -ntd = Ignore Timing constraints in physical constraints file and do NOT
         # generate timing constraints automatically.
   # <infile>  = Name of input NCD file.
   # <outfile> = Name of output NCD file or output directory.
               # Use format "<outfile>.ncd" or "<outfile>.dir".
   # <pcffile> = Name of physical constraints file.

