#!/bin/bash
SP605=xc6slx45t-3-fgg484
LX45_2=xc6slx45-2-csg484
LX45_3=xc6slx45-3-csg484
LX75_2=xc6slx75-2-csg484
LX75_3=xc6slx75-3-csg484
LX100_2=xc6slx100-2-csg484
LX100_3=xc6slx100-3-csg484

if [ -r ../syn/syn_cfg.txt ]; then
    SYN_CFG=`cat ../syn/syn_cfg.txt`
else
    SYN_CFG="CPU_12_4"
fi

CORE_DIR=../../cores
if [ "$SYN_CFG" == "CPU_14_7" ]; then
    CPU_DIR=../cpu_14_7/implementation
else
    CPU_DIR=../cpu/implementation
fi

SYN_DIR=../../syn
SRC_DIR=src
XST_DIR=xst
args=("$@")

PROJ=$(pwd | gawk -F / '{split($NF,b,"-"); print b[1]}')
TYPE=$(pwd | gawk -F - '{split($NF,b,"-"); print b[1]}')
echo $PROJ
echo $TYPE
if [ $PROJ == "gige" ]; then
   PRO=gige_top
   case $TYPE  in
   lx45_3)
   DEVICE=$LX45_3
   ;;
   lx45_2)
   DEVICE=$LX45_2
   ;;
   lx75_2)
   DEVICE=$LX75_2
   ;;
   lx75_3)
   DEVICE=$LX75_3
   ;;
   lx100_3)
   DEVICE=$LX100_3
   ;;
   4Gbit)
   DEVICE=$LX100_3
   ;;
   *)
    echo "no device type set $PROJ $TYPE"

   exit 1;
   ;;
   esac
else 
  if [ $PROJ == "gvrd" ]; then
    PRO=gvrd
    DEVICE=$SP605
  else
    echo "no device type set $PROJ $TYPE"

  exit 1;
  fi
fi
echo "device type set $PROJ $TYPE"
echo "set device to $DEVICE"

if [ $# -eq 4 ]; then
   PRO="${args[0]}"
   SRC_DIR="${args[1]}";
   XST_DIR="${args[2]}";
   XST_RUN="${args[3]}";
   echo "*****************************************"
   echo "xst"
   echo "Number of arguments passed: $#"
   echo "starting xst for project $PRO"
   echo "see logfile $PRO.xst_log"
   echo "*****************************************"
else
   echo "*****************************************"
   echo "Number of arguments passed: $#"
   echo ""
   echo "usage: ./xst.sh <project> <src_dir> <xst_dir> <xst_run> <top>"
   echo "*****************************************"
   exit 1;
fi

mkdir $XST_DIR
chmod a+w $XST_DIR
cd $XST_DIR
mkdir xst

if [ -r ../$SRC_DIR/$PRO.prj ]; then
   echo "Found prj file ../$SRC_DIR/$PRO.prj"
   else
   echo "No prj file ../$SRC_DIR/$PRO.prj"
   exit 1;
fi
if [ -r ../$SRC_DIR/$PRO.xcf ]; then
   echo "Found constraint file ../$SRC_DIR/$PRO.xcf"
   else
   echo "No constraint file ../$SRC_DIR/$PRO.xcf"
   exit 1;
fi
echo "set" > $PRO.xst
cat  $SYN_DIR/xst_set.txt >> $PRO.xst
echo "run" >> $PRO.xst
echo "-uc ../$SRC_DIR/$PRO.xcf" >> $PRO.xst
echo "-ifn ../$SRC_DIR/$PRO.prj" >> $PRO.xst
echo "-ofn $PRO" >> $PRO.xst
echo "-p $DEVICE" >> $PRO.xst
echo "-top $PRO" >> $PRO.xst
echo "-sd {"$CORE_DIR $CPU_DIR"}" >> $PRO.xst
cat  $SYN_DIR/$XST_RUN >> $PRO.xst

  date > $PRO.xst_log
  echo "running    xst -ifn $PRO.xst -ofn $PRO.syn"
  xst -ifn $PRO.xst -ofn $PRO.syn | tee -a $PRO.xst_log
  if [ ${PIPESTATUS[0]} != 0 ]; then
     exit 1
  fi
  date >> $PRO.xst_log
  
  cd ..
exit;
